==> node-typescript_5.0.4%2Bds1.orig.tar.xz: TypeScript-5.0.4/tests/baselines/reference/moduleResolution/type-reference-from-secondary-location.js <==
//// [/root/src/app.ts]


//// [/root/node_modules/lib.d.ts]


Resolving "lib" from /root/src/app.ts typesRoots: [/root/src/types] with host that doesnt have directoryExists
Resolution:: {
  "resolvedTypeReferenceDirective": {
    "primary": false,
    "resolvedFileName": "/root/node_modules/lib.d.ts",
    "isExternalLibraryImport": true
  },
  "failedLookupLocations": [
    "/root/src/types/lib/package.json",
    "/root/src/types/lib/index.d.ts",
    "/root/src/node_modules/lib/package.json",
    "/root/src/node_modules/lib.d.ts",
    "/root/src/node_modules/lib/index.d.ts",
    "/root/src/node_modules/@types/lib/package.json",
    "/root/src/node_modules/@types/lib.d.ts",
    "/root/src/node_modules/@types/lib/index.d.ts",
    "/root/node_modules/lib/package.json"
  ]
}

//// [/root/src/app.ts]


//// [/root/node_modules/lib/index.d.ts]


Resolving "lib" from /root/src/app.ts typesRoots: [/root/src/types] with host that doesnt have directoryExists
Resolution:: {
  "resolvedTypeReferenceDirective": {
    "primary": false,
    "resolvedFileName": "/root/node_modules/lib/index.d.ts",
    "isExternalLibraryImport": true
  },
  "failedLookupLocations": [
    "/root/src/types/lib/package.json",
    "/root/src/types/lib/index.d.ts",
    "/root/src/node_modules/lib/package.json",
    "/root/src/node_modules/lib.d.ts",
    "/root/src/node_modules/lib/index.d.ts",
    "/root/src/node_modules/@types/lib/package.json",
    "/root/src/node_modules/@types/lib.d.ts",
    "/root/src/node_modules/@types/lib/index.d.ts",
    "/root/node_modules/lib/package.json",
    "/root/node_modules/lib.d.ts"
  ]
}

//// [/root/src/app.ts]


//// [/root/node_modules/lib/typings/lib.d.ts]


//// [/root/node_modules/lib/package.json]
{"typings":"typings/lib.d.ts"}

Resolving "lib" from /root/src/app.ts typesRoots: [/root/src/types] with host that doesnt have directoryExists
Resolution:: {
  "resolvedTypeReferenceDirective": {
    "primary": false,
    "resolvedFileName": "/root/node_modules/lib/typings/lib.d.ts",
    "isExternalLibraryImport": true
  },
  "failedLookupLocations": [
    "/root/src/types/lib/package.json",
    "/root/src/types/lib/index.d.ts",
    "/root/src/node_modules/lib/package.json",
    "/root/src/node_modules/lib.d.ts",
    "/root/src/node_modules/lib/index.d.ts",
    "/root/src/node_modules/@types/lib/package.json",
    "/root/src/node_modules/@types/lib.d.ts",
    "/root/src/node_modules/@types/lib/index.d.ts",
    "/root/node_modules/lib.d.ts"
  ],
  "affectingLocations": [
    "/root/node_modules/lib/package.json"
  ]
}

//// [/root/src/app.ts]


//// [/root/node_modules/@types/lib/index.d.ts]


Resolving "lib" from /root/src/app.ts typesRoots: [/root/src/types] with host that doesnt have directoryExists
Resolution:: {
  "resolvedTypeReferenceDirective": {
    "primary": false,
    "resolvedFileName": "/root/node_modules/@types/lib/index.d.ts",
    "isExternalLibraryImport": true
  },
  "failedLookupLocations": [
    "/root/src/types/lib/package.json",
    "/root/src/types/lib/index.d.ts",
    "/root/src/node_modules/lib/package.json",
    "/root/src/node_modules/lib.d.ts",
    "/root/src/node_modules/lib/index.d.ts",
    "/root/src/node_modules/@types/lib/package.json",
    "/root/src/node_modules/@types/lib.d.ts",
    "/root/src/node_modules/@types/lib/index.d.ts",
    "/root/node_modules/lib/package.json",
    "/root/node_modules/lib.d.ts",
    "/root/node_modules/lib/index.d.ts",
    "/root/node_modules/@types/lib/package.json",
    "/root/node_modules/@types/lib.d.ts"
  ]
}

//// [/root/src/app.ts]


//// [/root/node_modules/@types/lib/typings/lib.d.ts]


//// [/root/node_modules/@types/lib/package.json]
{"typings":"typings/lib.d.ts"}

Resolving "lib" from /root/src/app.ts typesRoots: [/root/src/types] with host that doesnt have directoryExists
Resolution:: {
  "resolvedTypeReferenceDirective": {
    "primary": false,
    "resolvedFileName": "/root/node_modules/@types/lib/typings/lib.d.ts",
    "isExternalLibraryImport": true
  },
  "failedLookupLocations": [
    "/root/src/types/lib/package.json",
    "/root/src/types/lib/index.d.ts",
    "/root/src/node_modules/lib/package.json",
    "/root/src/node_modules/lib.d.ts",
    "/root/src/node_modules/lib/index.d.ts",
    "/root/src/node_modules/@types/lib/package.json",
    "/root/src/node_modules/@types/lib.d.ts",
    "/root/src/node_modules/@types/lib/index.d.ts",
    "/root/node_modules/lib/package.json",
    "/root/node_modules/lib.d.ts",
    "/root/node_modules/lib/index.d.ts",
    "/root/node_modules/@types/lib.d.ts"
  ],
  "affectingLocations": [
    "/root/node_modules/@types/lib/package.json"
  ]
}

==> node-typescript_5.1.6%2Bds1.orig.tar.xz: TypeScript-5.1.6/tests/baselines/reference/moduleResolution/type-reference-from-secondary-location.js <==
//// [/root/src/app.ts]


//// [/root/node_modules/lib.d.ts]


Resolving "lib" from /root/src/app.ts typesRoots: [/root/src/types] with host that doesnt have directoryExists
Resolution:: {
  "resolvedTypeReferenceDirective": {
    "primary": false,
    "resolvedFileName": "/root/node_modules/lib.d.ts",
    "isExternalLibraryImport": true
  },
  "failedLookupLocations": [
    "/root/src/types/lib.d.ts",
    "/root/src/types/lib/package.json",
    "/root/src/types/lib/index.d.ts",
    "/root/src/node_modules/lib/package.json",
    "/root/src/node_modules/lib.d.ts",
    "/root/src/node_modules/lib/index.d.ts",
    "/root/src/node_modules/@types/lib/package.json",
    "/root/src/node_modules/@types/lib.d.ts",
    "/root/src/node_modules/@types/lib/index.d.ts",
    "/root/node_modules/lib/package.json"
  ]
}

//// [/root/src/app.ts]


//// [/root/node_modules/lib/index.d.ts]


Resolving "lib" from /root/src/app.ts typesRoots: [/root/src/types] with host that doesnt have directoryExists
Resolution:: {
  "resolvedTypeReferenceDirective": {
    "primary": false,
    "resolvedFileName": "/root/node_modules/lib/index.d.ts",
    "isExternalLibraryImport": true
  },
  "failedLookupLocations": [
    "/root/src/types/lib.d.ts",
    "/root/src/types/lib/package.json",
    "/root/src/types/lib/index.d.ts",
    "/root/src/node_modules/lib/package.json",
    "/root/src/node_modules/lib.d.ts",
    "/root/src/node_modules/lib/index.d.ts",
    "/root/src/node_modules/@types/lib/package.json",
    "/root/src/node_modules/@types/lib.d.ts",
    "/root/src/node_modules/@types/lib/index.d.ts",
    "/root/node_modules/lib/package.json",
    "/root/node_modules/lib.d.ts"
  ]
}

//// [/root/src/app.ts]


//// [/root/node_modules/lib/typings/lib.d.ts]


//// [/root/node_modules/lib/package.json]
{"typings":"typings/lib.d.ts"}

Resolving "lib" from /root/src/app.ts typesRoots: [/root/src/types] with host that doesnt have directoryExists
Resolution:: {
  "resolvedTypeReferenceDirective": {
    "primary": false,
    "resolvedFileName": "/root/node_modules/lib/typings/lib.d.ts",
    "isExternalLibraryImport": true
  },
  "failedLookupLocations": [
    "/root/src/types/lib.d.ts",
    "/root/src/types/lib/package.json",
    "/root/src/types/lib/index.d.ts",
    "/root/src/node_modules/lib/package.json",
    "/root/src/node_modules/lib.d.ts",
    "/root/src/node_modules/lib/index.d.ts",
    "/root/src/node_modules/@types/lib/package.json",
    "/root/src/node_modules/@types/lib.d.ts",
    "/root/src/node_modules/@types/lib/index.d.ts",
    "/root/node_modules/lib.d.ts"
  ],
  "affectingLocations": [
    "/root/node_modules/lib/package.json"
  ]
}

//// [/root/src/app.ts]


//// [/root/node_modules/@types/lib/index.d.ts]


Resolving "lib" from /root/src/app.ts typesRoots: [/root/src/types] with host that doesnt have directoryExists
Resolution:: {
  "resolvedTypeReferenceDirective": {
    "primary": false,
    "resolvedFileName": "/root/node_modules/@types/lib/index.d.ts",
    "isExternalLibraryImport": true
  },
  "failedLookupLocations": [
    "/root/src/types/lib.d.ts",
    "/root/src/types/lib/package.json",
    "/root/src/types/lib/index.d.ts",
    "/root/src/node_modules/lib/package.json",
    "/root/src/node_modules/lib.d.ts",
    "/root/src/node_modules/lib/index.d.ts",
    "/root/src/node_modules/@types/lib/package.json",
    "/root/src/node_modules/@types/lib.d.ts",
    "/root/src/node_modules/@types/lib/index.d.ts",
    "/root/node_modules/lib/package.json",
    "/root/node_modules/lib.d.ts",
    "/root/node_modules/lib/index.d.ts",
    "/root/node_modules/@types/lib/package.json",
    "/root/node_modules/@types/lib.d.ts"
  ]
}

//// [/root/src/app.ts]


//// [/root/node_modules/@types/lib/typings/lib.d.ts]


//// [/root/node_modules/@types/lib/package.json]
{"typings":"typings/lib.d.ts"}

Resolving "lib" from /root/src/app.ts typesRoots: [/root/src/types] with host that doesnt have directoryExists
Resolution:: {
  "resolvedTypeReferenceDirective": {
    "primary": false,
    "resolvedFileName": "/root/node_modules/@types/lib/typings/lib.d.ts",
    "isExternalLibraryImport": true
  },
  "failedLookupLocations": [
    "/root/src/types/lib.d.ts",
    "/root/src/types/lib/package.json",
    "/root/src/types/lib/index.d.ts",
    "/root/src/node_modules/lib/package.json",
    "/root/src/node_modules/lib.d.ts",
    "/root/src/node_modules/lib/index.d.ts",
    "/root/src/node_modules/@types/lib/package.json",
    "/root/src/node_modules/@types/lib.d.ts",
    "/root/src/node_modules/@types/lib/index.d.ts",
    "/root/node_modules/lib/package.json",
    "/root/node_modules/lib.d.ts",
    "/root/node_modules/lib/index.d.ts",
    "/root/node_modules/@types/lib.d.ts"
  ],
  "affectingLocations": [
    "/root/node_modules/@types/lib/package.json"
  ]
}
